using DamageAssesment.Api.Employees.Db;
using DamageAssesment.Api.Employees.Interfaces;
using DamageAssesment.Api.Employees.Providers;
using Microsoft.EntityFrameworkCore;
using System.Reflection;

var builder = WebApplication.CreateBuilder(args);


// CORS setup to allow requests from any origin.
builder.Services.AddCors(p => p.AddPolicy("DamageAppCorsPolicy", build => {
    build.WithOrigins("*").AllowAnyMethod().AllowAnyHeader().AllowAnyOrigin();
}));


// Add services to the container.
builder.Services.AddControllers();
// Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
builder.Services.AddEndpointsApiExplorer();
// Add Swagger/OpenAPI documentation support.
builder.Services.AddSwaggerGen(c =>
{
    // Include XML comments from your assembly
    var xmlFile = $"{Assembly.GetExecutingAssembly().GetName().Name}.xml";
    var xmlPath = Path.Combine(AppContext.BaseDirectory, xmlFile);
    c.IncludeXmlComments(xmlPath);
});

builder.Services.AddScoped<IEmployeesProvider, EmployeesProvider>();
builder.Services.AddAutoMapper(AppDomain.CurrentDomain.GetAssemblies()); //4/30
builder.Services.AddDbContext<EmployeeDbContext>(option =>
{
    option.UseSqlServer("EmployeeConnection");
});
builder.Services.AddCors(p => p.AddPolicy("DamageAppCorsPolicy", build => {
    build.WithOrigins("*").AllowAnyMethod().AllowAnyHeader().AllowAnyOrigin();
}));
var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseSwagger();
    app.UseSwaggerUI();

    using (var serviceScope = app.Services.CreateScope())
    {
        var services = serviceScope.ServiceProvider;
        var employeesProvider = services.GetRequiredService<IEmployeesProvider>();
        employeesProvider.SeedData();
    }
}
<<<<<<< HEAD
app.UseCors("DamageAppCorsPolicy");
=======

// Enable CORS, authentication, and authorization middleware.
app.UseCors("DamageAppCorsPolicy");

>>>>>>> 9ec9b8b96fc7c5767fcddf1e4e52bde203fcf619
app.UseAuthorization();

app.MapControllers();

app.Run();
