using DamageAssesment.Api.Questions.Db;
using DamageAssesment.Api.Questions.Interfaces;
using DamageAssesment.Api.Questions.Providers;
using Microsoft.EntityFrameworkCore;
using System.Reflection;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.

builder.Services.AddControllers();

// Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle

builder.Services.AddScoped<IQuestionsProvider, QuestionsProvider>();
builder.Services.AddAutoMapper(AppDomain.CurrentDomain.GetAssemblies());

// CORS setup to allow requests from any origin.
builder.Services.AddCors(p => p.AddPolicy("DamageAppCorsPolicy", build => {
    build.WithOrigins("*").AllowAnyMethod().AllowAnyHeader().AllowAnyOrigin();
}));

// Add controller services and API Explorer for endpoint discovery.
builder.Services.AddEndpointsApiExplorer();
// Add Swagger/OpenAPI documentation support.
builder.Services.AddSwaggerGen(c =>
{
    // Include XML comments from your assembly
    var xmlFile = $"{Assembly.GetExecutingAssembly().GetName().Name}.xml";
    var xmlPath = Path.Combine(AppContext.BaseDirectory, xmlFile);
    c.IncludeXmlComments(xmlPath);
});
builder.Services.AddDbContext<QuestionDbContext>(option =>
{
    option.UseSqlServer("QuestionConnection");
});
builder.Services.AddCors(p => p.AddPolicy("DamageAppCorsPolicy", build => {
    build.WithOrigins("*").AllowAnyMethod().AllowAnyHeader().AllowAnyOrigin();
}));
var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseSwagger();
    app.UseSwaggerUI();

    using (var serviceScope = app.Services.CreateScope())
    {
        var services = serviceScope.ServiceProvider;
        var questionProvider = services.GetRequiredService<IQuestionsProvider>();
        questionProvider.SeedData();
    }
}
<<<<<<< HEAD
=======

// Enable CORS, authentication, and authorization middleware.
>>>>>>> 9ec9b8b96fc7c5767fcddf1e4e52bde203fcf619
app.UseCors("DamageAppCorsPolicy");
app.UseAuthorization();

app.MapControllers();

app.Run();
